@@ -10,7 +10,29 @@ Character encoding support for Rust. (also known as `rust-encoding`)
 It is based on [WHATWG Encoding Standard](http://encoding.spec.whatwg.org/),
 and also provides an advanced interface for error detection and recovery.
 
-## Simple Usage
+## Usage
+
+Put this in your `Cargo.toml`:
+
+```toml
+[dependencies]
+encoding = "0.2"
+```
+
+Or in the case you are using Rust 1.0 beta, pin the exact version:
+
+```toml
+[dependencies]
+encoding = "=0.2.28"
+```
+
+And this in your crate root:
+
+```rust
+extern crate encoding;
+```
+
+## Overview
 
 To encode a string:
 
@@ -102,7 +124,7 @@ assert_eq!(WINDOWS_949.decode(broken, DecoderTrap::Replace),
            Ok("\u{c6b0}\u{c640}\u{fffd}\u{c559}".to_string()));
 ~~~~
 
-## Detailed Usage
+## Types and Stuffs
 
 There are three main entry points to Encoding.
 
@@ -172,9 +194,7 @@ Whenever in doubt, look at the source code and specifications for detailed expla
 
 */
 
-#![feature(into_cow)]
-#![feature(str_char)] // lib stability features as per RFC #507
-#![cfg_attr(test, feature(core, collections, test))] // ditto
+#![cfg_attr(test, feature(test))] // lib stability features as per RFC #507
 
 extern crate encoding_index_singlebyte as index_singlebyte;
 extern crate encoding_index_korean as index_korean;
