@@ -240,8 +240,8 @@ pub trait RawDecoder: 'static {
     #[cfg(test)]
     fn test_concat(&self, a: &[u8], b: &[u8]) -> Vec<u8> {
         let mut v = Vec::with_capacity(a.len() + b.len());
-        v.push_all(a);
-        v.push_all(b);
+        v.extend(a.iter().cloned());
+        v.extend(b.iter().cloned());
         v
     }
 }
@@ -393,6 +393,17 @@ impl DecoderTrap {
     }
 }
 
+impl Clone for DecoderTrap {
+    fn clone(&self) -> DecoderTrap {
+        match *self {
+            DecoderTrap::Strict => DecoderTrap::Strict,
+            DecoderTrap::Replace => DecoderTrap::Replace,
+            DecoderTrap::Ignore => DecoderTrap::Ignore,
+            DecoderTrap::Call(f) => DecoderTrap::Call(f),
+        }
+    }
+}
+
 #[stable]
 #[derive(Copy)]
 pub enum EncoderTrap {
@@ -448,6 +459,18 @@ impl EncoderTrap {
     }
 }
 
+impl Clone for EncoderTrap {
+    fn clone(&self) -> EncoderTrap {
+        match *self {
+            EncoderTrap::Strict => EncoderTrap::Strict,
+            EncoderTrap::Replace => EncoderTrap::Replace,
+            EncoderTrap::Ignore => EncoderTrap::Ignore,
+            EncoderTrap::NcrEscape => EncoderTrap::NcrEscape,
+            EncoderTrap::Call(f) => EncoderTrap::Call(f),
+        }
+    }
+}
+
 /// Determine the encoding by looking for a Byte Order Mark (BOM)
 /// and decoded a single string in memory.
 /// Return the result and the used encoding.
@@ -471,7 +494,7 @@ mod tests {
     use super::*;
     use super::EncoderTrap::NcrEscape;
     use util::StrCharIndex;
-    use std::borrow::IntoCow;
+    use std::convert::Into;
 
     // a contrived encoding example: same as ASCII, but inserts `prepend` between each character
     // within two "e"s (so that `widespread` becomes `wide*s*p*r*ead` and `eeeeasel` becomes
@@ -498,7 +521,7 @@ mod tests {
                     }
                 } else {
                     return (i, Some(CodecError { upto: j as isize,
-                                                 cause: "!!!".into_cow() }));
+                                                 cause: "!!!".into() }));
                 }
             }
             (input.len(), None)
